@@ -8,6 +8,6 @@ pub struct TokenDto {
 
 impl TokenDto { 
     pub fn from_query_result(result: LoginQueryResult) -> Self{
-       TokenDto {jwt: String::from("someJwt")} 
+       TokenDto {jwt: result.token().value().clone()} 
     }
 }
